@@ -55,7 +55,7 @@ LOGGER = logging.getLogger(__name__)
 DISCRIMINATOR = "type"
 
 
-class StoreExitsError(Exception):
+class StoreExistsError(Exception):
     pass
 
 
@@ -87,7 +87,7 @@ class ForensicStore:
                 raise TypeError("File needs to end with '.forensicstore'")
             exists = os.path.exists(url)
             if exists and create:
-                raise StoreExitsError
+                raise StoreExistsError
             if not create and not exists:
                 raise StoreNotExitsError
             if url[-1] == "/":
@@ -128,6 +128,7 @@ class ForensicStore:
         else:
             self.fs = SQLiteFS(connection=self.connection)
 
+        self.application_id = application_id
         self._updated = False
         self._views = self._get_views()
         self._schemas = dict()
@@ -205,7 +206,7 @@ class ForensicStore:
 
             return self._row_to_element(result)
         except sqlite3.OperationalError as error:
-            raise KeyError(error)
+            raise KeyError(error) from error
         finally:
             cur.close()
 
@@ -286,9 +287,12 @@ class ForensicStore:
         """
         if self._updated:
             self.create_views()
-        self.fs.close()
-        # self.connection.commit()
-        # self.connection.close()
+        self.fs.close()  # also closes the SQLite database if we use sqlitefs
+
+        if self.application_id == ELEMENTARY_APPLICATION_ID_DIR_FS:
+            # otherwise, close it here
+            self.connection.commit()
+            self.connection.close()
 
     def create_views(self):
         cur = self.connection.cursor()
@@ -673,12 +677,12 @@ class ForensicStore:
             specifying the default value in a registry key, an empty string MUST be used.
         """
         values = self.get(key_id).get("values", [])
-        if data_type in ("REG_SZ", "REG_EXPAND_SZ"):
-            strdata = data.decode("utf-16")
+        if data_type in ("REG_SZ", "REG_EXPAND_SZ", "REG_MULTI_SZ"):
+            strdata = data.decode("utf-16").strip('\x00')
+            # REG_MULTI_SZ is split by null bytes, replace them with ascii unit separator
+            strdata = strdata.replace('\x00', '\x1f')
         elif data_type in ("REG_DWORD", "REG_QWORD"):
             strdata = "%d" % int.from_bytes(data, "little")
-        elif data_type == "MULTI_SZ":
-            strdata = " ".join(data.decode("utf-16").split("\x00"))
         else:
             hexdata = data.hex()
             strdata = ' '.join(a + b for a, b in zip(hexdata[::2], hexdata[1::2]))
